@@ -6,4 +6,7 @@ class Paginator(Paginator):
 
     @cached_property
     def count(self):
-        return self.object_list.count()
+        try:
+            return self.object_list.count()
+        except TypeError:
+            return len(self.object_list)
